add_track_data: Add track data to ping data.

Description Usage Arguments Details Value Author(s)

Description

For an input dataframe containing tracking data, adds the following columns: * _ping_time_next_pnt_ - POSIX column representing the time at the next point in the track. * _dist_to_next_pnt_ - The distance in meters to next point in the track. * _sec_to_next_pnt_ - the time in seconds between the current point and the next point in the track. * _track_id_ - An integer value identifying all points within the same track * _pnt_in_track_ - An integer value incrementing per point in each track * _calc_speed_ - The calculated speed at the point in meters/second, based on the distance to the next point divided by the time to the next point.

Usage

1
2
add_track_data(data, id, timestamp, latitude, longitude, daysplit,
  timesplit = -1L, distsplit = -1L)

Arguments

data

**Dataframe** - input data.

id

**String** - column name that contains the tracking device ID, used to group tracks.

timestamp

**String** - POSIXct column name that contains the timestamp of tracking data for each point.

daysplit

**Boolean** - If True, tracks be split at the end of each calendar day.

timesplit

**Optional** **Integer** - Split tracks if more than this many minutes between pings.

distsplit

**Optional** **Integer** - Split tracks if more than this many meters between pings.

Details

The input dataframe should be sorted by device identifier and ping time.

Value

Dataframe of tracking data.

Author(s)

Bill DeVoe, William.DeVoe@maine.gov


bdevoe/VesselTrackeR documentation built on June 1, 2019, 4:58 a.m.