add_track_data_old: Add track data to ping data.

Description Usage Arguments Value Author(s)

Description

For an input SP dataframe containing tracking data, adds the following columns: * _TimeAtNextPoint_ - POSIX column representing the time at the next point in the track. * _DistToNextPoint_ - The distance in meters to next point in the track. * _TimeAtPoint_ - the time between the current point and the next point in the track. * _TrackID_ - An integer value identifying all points within the same track. * _PointInTrack_ - An integer value incrementing per point in each track * _CalcSpeed_ - The calculated speed at the point in meters/second, based on the distance to the next point divided by the time to the next point.

Usage

1
2
add_track_data_old(data, id = "deviceId", timestamp = "updateTime",
  daysplit = F, timesplit = NULL, distsplit = NULL)

Arguments

data

**SpatialPointsDataFrame** - input data.

id

**String** - column name that contains the tracking device ID, used to group tracks.

timestamp

**String** - POSIXct column name that contains the timestamp of tracking data for each point.

daysplit

**Boolean** - If True, tracks be split at the end of each calendar day.

timesplit

**Optional** **Integer** - Split tracks if more than this many minutes between pings.

distsplit

**Optional** **Integer** - Split tracks if more than this many meters between pings.

Value

SpatialPointsDataframe of tracking data.

Author(s)

Bill DeVoe, William.DeVoe@maine.gov


bdevoe/VesselTrackeR documentation built on June 1, 2019, 4:58 a.m.