fb_all_data: All FB Sentry data for all devices for date range

Description Usage Arguments Value Author(s)

Description

Pulls all data from FB Sentry API profile for a given date range.

Usage

1
2
fb_all_data(url = "https://fb-sentrygps.com/api/v2/", key, timebegin,
  timeend, local = T, short = T, devices)

Arguments

url

**String** - URL to the FB Sentry API; defaults to version 2 URL.

key

**String** - Name of the Windows environment variable containing the API key.

timebegin

**String** - Retrieve reports after this datetime (UTC). Format: MM/dd/yyyy HH:mm:ss

timeend

**String** - Retrieve reports before this datetime (UTC). Format: MM/dd/yyyy HH:mm:ss

local

**Boolean** - Convert timestamps to local timezone. Default True

short

**Boolean** *Optional* - Indicate whether to return short or long version of report; defaults to true (short).

devices

**Character Vector** *Optional* - deviceIDs to include in the returned data.

Value

SpatialPoints Dataframe of tracking data.

Author(s)

Bill DeVoe, William.DeVoe@maine.gov


bdevoe/VesselTrackeR documentation built on June 1, 2019, 4:58 a.m.