fb_validate_date: Validate FB Sentry date string

Description Usage Arguments Value Author(s)

Description

Checks that a provided date string is properly formated for the API call.

Usage

1

Arguments

date

**String** - Datetime argument

Value

Boolean; true if properly formatted. An error is thrown if the data is improperly formatted.

Author(s)

Bill DeVoe, William.DeVoe@maine.gov


bdevoe/VesselTrackeR documentation built on June 1, 2019, 4:58 a.m.