fb_validate_key: Validate FB Sentry API key

Description Usage Arguments Value Author(s)

Description

Tests the connection to the FB Sentry API

Usage

1
2
fb_validate_key(url = "https://fb-sentrygps.com/api/v2/", key,
  stop = T)

Arguments

url

**String** - URL to the FB Sentry API; defaults to version 2 URL.

key

**String** - Name of the Windows environment variable containing the API key.

stop

**Boolean** - If false, the function will return a false value if the connection fails; if true (the default), the function will stop.

Value

Boolean; true if connection was successful.

Author(s)

Bill DeVoe, William.DeVoe@maine.gov


bdevoe/VesselTrackeR documentation built on June 1, 2019, 4:58 a.m.