Description Usage Arguments Value Author(s)
For an input SP dataframe containing tracking data, adds the following columns: * _TimeAtNextPoint_ - POSIX column representing the time at the next point in the track. * _DistToNextPoint_ - The distance in meters to next point in the track. * _TimeAtPoint_ - the time between the current point and the next point in the track. * _TrackID_ - An integer value identifying all points within the same track. * _PointInTrack_ - An integer value incrementing per point in each track * _CalcSpeed_ - The calculated speed at the point in meters/second, based on the distance to the next point divided by the time to the next point.
1 2 | add_track_data_old(data, id = "deviceId", timestamp = "updateTime",
daysplit = F, timesplit = NULL, distsplit = NULL)
|
data |
**SpatialPointsDataFrame** - input data. |
id |
**String** - column name that contains the tracking device ID, used to group tracks. |
timestamp |
**String** - POSIXct column name that contains the timestamp of tracking data for each point. |
daysplit |
**Boolean** - If True, tracks be split at the end of each calendar day. |
timesplit |
**Optional** **Integer** - Split tracks if more than this many minutes between pings. |
distsplit |
**Optional** **Integer** - Split tracks if more than this many meters between pings. |
SpatialPointsDataframe of tracking data.
Bill DeVoe, William.DeVoe@maine.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.