Description Usage Arguments Value Author(s)
Pulls all data from FB Sentry API profile for a given date range.
1 2 | fb_all_data(url = "https://fb-sentrygps.com/api/v2/", key, timebegin,
timeend, local = T, short = T, devices)
|
url |
**String** - URL to the FB Sentry API; defaults to version 2 URL. |
key |
**String** - Name of the Windows environment variable containing the API key. |
timebegin |
**String** - Retrieve reports after this datetime (UTC). Format: MM/dd/yyyy HH:mm:ss |
timeend |
**String** - Retrieve reports before this datetime (UTC). Format: MM/dd/yyyy HH:mm:ss |
local |
**Boolean** - Convert timestamps to local timezone. Default True |
short |
**Boolean** *Optional* - Indicate whether to return short or long version of report; defaults to true (short). |
devices |
**Character Vector** *Optional* - deviceIDs to include in the returned data. |
SpatialPoints Dataframe of tracking data.
Bill DeVoe, William.DeVoe@maine.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.