Description Usage Arguments Value Author(s)
Checks that a provided date string is properly formated for the API call.
1 |
date |
**String** - Datetime argument |
Boolean; true if properly formatted. An error is thrown if the data is improperly formatted.
Bill DeVoe, William.DeVoe@maine.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.