Description Usage Arguments Value Author(s)
Tests the connection to the FB Sentry API
1 2 | fb_validate_key(url = "https://fb-sentrygps.com/api/v2/", key,
stop = T)
|
url |
**String** - URL to the FB Sentry API; defaults to version 2 URL. |
key |
**String** - Name of the Windows environment variable containing the API key. |
stop |
**Boolean** - If false, the function will return a false value if the connection fails; if true (the default), the function will stop. |
Boolean; true if connection was successful.
Bill DeVoe, William.DeVoe@maine.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.